==> haskell-aeson-pretty-0.7.2-9-armv7h.pkg.tar.xz: usr/share/haskell/haskell-aeson-pretty/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-pretty
version: 0.7.2
id: aeson-pretty-0.7.2-38276a5fbe9d416306eeea651da7225e
key: aeson_7xMcRIYqZ2zKl5sq1hVrNK
license: BSD3
copyright: Copyright 2011 Falko Peters
maintainer: Falko Peters <falko.peters@gmail.com>
stability: experimental
homepage: http://github.com/informatikr/aeson-pretty
synopsis: JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.
    .
    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.
    .
    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this
    .
    > cabal install -flib-only aeson-pretty
    .
    the command-line tool will NOT be installed.
category: Text, Web, JSON, Pretty Printer
author: Falko Peters <falko.peters@gmail.com>
exposed: True
exposed-modules:
    Data.Aeson.Encode.Pretty
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-pretty-0.7.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-pretty-0.7.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-pretty-0.7.2
hs-libraries: HSaeson-pretty-0.7.2-7xMcRIYqZ2zKl5sq1hVrNK
depends:
    aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock
haddock-html: /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-pretty-0.7.2-10-armv7h.pkg.tar.xz: usr/share/haskell/haskell-aeson-pretty/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-pretty
version: 0.7.2
id: aeson-pretty-0.7.2-79948fcfb4ff99108a7609ce21eccf5e
key: aeson_K96upfOIXDUKpxGYZe6f5S
license: BSD3
copyright: Copyright 2011 Falko Peters
maintainer: Falko Peters <falko.peters@gmail.com>
stability: experimental
homepage: http://github.com/informatikr/aeson-pretty
synopsis: JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.
    .
    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.
    .
    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this
    .
    > cabal install -flib-only aeson-pretty
    .
    the command-line tool will NOT be installed.
category: Text, Web, JSON, Pretty Printer
author: Falko Peters <falko.peters@gmail.com>
exposed: True
exposed-modules:
    Data.Aeson.Encode.Pretty
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-pretty-0.7.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-pretty-0.7.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-pretty-0.7.2
hs-libraries: HSaeson-pretty-0.7.2-K96upfOIXDUKpxGYZe6f5S
depends:
    aeson-0.11.1.0-01f93b6d659087121e16b9df8deda57c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock
haddock-html: /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
